﻿using UnityEngine;
using UnityEngine.SceneManagement;
using System.Collections;

public class Player : MonoBehaviour
{
	// 8.0fはRigidbody2DのGravityScaleを5にしたときのいい感じの初期値
	public float speed = 8.0f;
	public float jumpForce = 800.0f;

	public GameObject bulletPrefab;
	public ParticleSystem particleSystemBloodPrefab;

	private Rigidbody2D myRigidbody2D;

	private float movement;
	private bool isJump;
	private bool isAttack;
	private bool isDead;

	static Vector3 FlipX = new Vector3 (-1, 1, 1);

	void Start ()
	{
		myRigidbody2D = GetComponent<Rigidbody2D> ();
	}

	void Update ()
	{
		if (isDead)
			return;
		
		movement = Input.GetAxis ("Horizontal");	// Aキー,Wキー
		if (!isJump) {
			isJump = Input.GetButtonDown ("Jump");		// スペースキー
		}

		isAttack = Input.GetButtonDown ("Fire1");	// 左マウスボタン
	}

	void FixedUpdate ()
	{
		if (isDead)
			return;
		
		// Flip
		if (movement > 0) {
			transform.localScale = Vector3.one;
		} else if (movement < 0) {
			transform.localScale = FlipX;
		}

		// 移動処理
		myRigidbody2D.velocity = new Vector2 (movement * speed, myRigidbody2D.velocity.y);

		// 攻撃処理
		if (isAttack) {
			Attack ();
			isAttack = false;
		}

		// ジャンプ処理
		if (isJump) {
			myRigidbody2D.AddForce (new Vector2 (0, jumpForce));
		}
		isJump = false;
	}

	void Attack ()
	{
		if (isDead)
			return;
		
		// 弾丸生成
		Vector3 direction;
		if (transform.localScale.x > 0) {
			// 右向き
			direction = Vector3.right;
		} else {
			direction = Vector3.left;
		}
		var obj = Instantiate (bulletPrefab, transform.position + (direction / 2f), transform.rotation) as GameObject;
		obj.GetComponent<Bullet> ().direction = direction.x;
	}

	public void TakeDamage ()
	{
		if (isDead)
			return;
		
		isDead = true;

		// 死亡時エフェクト
		Instantiate (particleSystemBloodPrefab, transform.position, transform.rotation);
		GetComponent<AudioSource> ().Play ();

		GetComponent<SpriteRenderer> ().enabled = false;

		StartCoroutine (ReloadScene ());

	}

	IEnumerator ReloadScene ()
	{
		yield return new WaitForSeconds (1.5f);

		SceneManager.LoadScene (SceneManager.GetActiveScene ().name);

		yield return null;
	}
}
